Package: unifiedWMWqPCR
Type: Package
Title: Unified Wilcoxon-Mann Whitney Test for testing differential
        expression in qPCR data
Version: 1.49.0
Date: 2018-04-23
Author: Jan R. De Neve & Joris Meys
Maintainer: Joris Meys <Joris.Meys@UGent.be>
Description: This packages implements the unified Wilcoxon-Mann-Whitney
    Test for qPCR data. This modified test allows for testing
    differential expression in qPCR data.
License: GPL (>=2)
Encoding: UTF-8
Depends: methods
Imports: BiocGenerics, limma, stats, graphics
Collate: 'Datasets.R' 'S3Generics.R' 'uwmwEstimate_Class.R'
        'uwmwRes_Class.R' 'allGenerics.R' 'as.matrix.uwmwEstimate.R'
        'as.matrix.uwmwRes.R' 'forestplot_methods.R'
        'getEstimate_methods.R' 'groups.message.R' 'outer.h.f.R'
        'outer.o.f.R' 'plotMethoduwmwRes.R' 'prepdf.R' 'sandwich1.f.R'
        'sandwich2.f.R' 'sandwich3.f.R' 'sort.uwmwRes.R' 'uWMW.H.R'
        'uWMW.O.R' 'uWMW_Extract.R' 'uWMW_internal.R' 'uWMW_methods.R'
        'unifiedWMWqPCR-package.R' 'uwmw_Accessors.R'
        'uwmw_Showmethods.R' 'volcanoplot.R' 'volcano-internal.R'
        'wmw.f.R'
biocViews: DifferentialExpression, GeneExpression,
        MicrotitrePlateAssay, MultipleComparison, QualityControl,
        Software, Visualization, qPCR
RoxygenNote: 7.3.2
git_url: https://git.bioconductor.org/packages/unifiedWMWqPCR
git_branch: devel
git_last_commit: a0757eb
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 01:42:33 UTC; biocbuild
